@@ -1,4 +1,5 @@
 from django.contrib import admin
+from django.utils.translation import ugettext_lazy as _
 
 from tendenci.core.perms.admin import TendenciBaseModelAdmin
 from tendenci.addons.news.models import News
@@ -10,7 +11,7 @@ class NewsAdmin(TendenciBaseModelAdmin):
     prepopulated_fields = {'slug': ['headline']}
     search_fields = ['headline', 'body']
     fieldsets = (
-        ('News Information', {
+        (_('News Information'), {
             'fields': ('headline',
                 'slug',
                 'summary',
@@ -23,8 +24,8 @@ class NewsAdmin(TendenciBaseModelAdmin):
                 'timezone',
                 )
         }),
-        ('Contributor', {'fields': ('contributor_type',)}),
-        ('Author', {'fields': ('first_name',
+        (_('Contributor'), {'fields': ('contributor_type',)}),
+        (_('Author'), {'fields': ('first_name',
                                  'last_name',
                                  'google_profile',
                                  'phone',
@@ -33,13 +34,13 @@ class NewsAdmin(TendenciBaseModelAdmin):
                                  ),
                  'classes': ('contact',),
         }),
-        ('Permissions', {'fields': ('allow_anonymous_view',)}),
-        ('Advanced Permissions', {'classes': ('collapse',), 'fields': (
+        (_('Permissions'), {'fields': ('allow_anonymous_view',)}),
+        (_('Advanced Permissions'), {'classes': ('collapse',), 'fields': (
             'user_perms',
             'member_perms',
             'group_perms',
             )}),
-        ('Publishing Status', {'fields': (
+        (_('Publishing Status'), {'fields': (
             'syndicate',
             'status_detail',
         )}),
